@@ -41,7 +41,7 @@ class JsonTypeGzipped(types.TypeDecorator):
     def process_bind_param(self, value, dialect):
         value = dumps(value)
         out = StringIO()
-        with GzipFile(fileobj=out, mode="w") as f:
+        with GzipFile(fileobj=out, mode="w", mtime=0) as f:
             f.write(value)
         return out.getvalue()
 
@@ -64,3 +64,4 @@ from holmes.models.request import Request  # NOQA
 from holmes.models.user import User  # NOQA
 from holmes.models.limiter import Limiter # NOQA
 from holmes.models.domains_violations_prefs import DomainsViolationsPrefs # NOQA
+from holmes.models.users_violations_prefs import UsersViolationsPrefs # NOQA
